var system = require("../../../system");
var settings = require("../../../../config/settings");
const AppServiceBase = require("../../app.base");
const uuidv4 = require('uuid/v4');
const logCtl = system.getObject("service.common.oplogSve");
//商标查询操作
class UtilsNeedSve extends AppServiceBase {
  constructor() {
    super();
    this.execlient = system.getObject("util.execClient");
    this.channelApiUrl = settings.channelApiUrl();
    this.centerChannelUrl = settings.centerChannelUrl();
    this.appInfo = {
      aliyuntmtransfer: { appkey: settings.appKey, secret: settings.secret }
    };
  }


  async getCenterToken() {
    var self = this;
    var reqTokenUrl = this.centerChannelUrl + "/api/opreceive/accessAuth/getAppTokenByAppKey";
    var reqParam = self.appInfo["aliyuntmtransfer"];
    if (!reqParam.appkey || !reqParam.secret) {
      return system.getResult(null, "reqType类型有误，请求失败");
    }
    var param = {
      "actionType": "getAppTokenByAppKey",
      "actionBody": {
        "appkey": reqParam.appkey,
        "secret": reqParam.secret
      }
    };
    var rtn = await this.execlient.execPost(param, reqTokenUrl);
    if (!rtn.stdout) {
      return system.getResult(null, "获取token失败");
    }
    var tokenResult = JSON.parse(rtn.stdout);
    return tokenResult;
  }

  getUUID() {
    var uuid = uuidv4();
    var u = uuid.replace(/\-/g, "");
    return u;
  }

  async reqcenterchannel(pobj) {
    var sobj = {
      "actionType": pobj.action_type,
      "actionBody": pobj
    }
    var self = this;
    var tokenInfo = await this.getCenterToken();
    if (tokenInfo.status != 0) {
      return {
        "requestId": self.getUUID(),
        "success": true,
        "errorMsg": "",
        "errorCode": "ok"
      };
    }
    var userpin = "";
    if (pobj.mobile) {
      //获取用户userpin
      var userparam = {
        actionType: "getLoginByUserName",
        actionBody: {
          "channelUserId": pobj.mobile,
          "mobile": pobj.mobile,
          "userName": pobj.mobile
        }
      };
      // pobj.actionBody.channelUserId = pobj.mobile;//渠道用户id，没有则用手机号
      // pobj.actionBody.mobile = pobj.mobile;//用户手机号
      var url = settings.centerChannelUrl() + "/api/opreceive/accessAuth/springBoard";
      var userpinResultTmp = await this.execlient.execPostTK(userparam, url, tokenInfo.data.token);
      if (userpinResultTmp.status != 0 && userpinResultTmp.status != 2060) {
        return system.getResultFail(-99, "获取userpin失败");
      }
      userpin = userpinResultTmp.data.userpin;
      if (!userpin) {
        return system.getResultFail(-88, "获取userpin失败!!");
      }
    }
    //带userpin请求
    url = settings.centerChannelUrl() + "/api/opreceive/need/springBoard";
    var token = tokenInfo.data.token;
    var rtn = null;
    var self = this;
    if (userpin) {
      rtn = await self.execlient.execDataPostByTokenUserPin(sobj, url, token, userpin);
    } else {
      rtn = await self.execlient.execPostTK(sobj, url, token);
      if (rtn.status == 0) {
        return {
          "requestId": rtn.requestId,
          "success": true,
          "errorMsg": "",
          "errorCode": "ok"
        };
      } else {
        return {
          "requestId": rtn.requestId,
          "success": false,
          "errorMsg": rtn.msg,
          "errorCode": "ok"
        };
      }
    }
    if (!rtn || !rtn.stdout) {
      return {
        "requestId": self.getUUID(),
        "success": false,
        "errorMsg": "网络错误",
        "errorCode": "ok"
      };
    }

    var result = JSON.parse(rtn.stdout);
    if (result.status == 0) {
      return {
        "requestId": result.requestId,
        "success": true,
        "errorMsg": "",
        "errorCode": "ok"
      };
    } else {
      return {
        "requestId": result.requestId,
        "success": false,
        "errorMsg": result.msg,
        "errorCode": "ok"
      };
    }
  }


  async paySuccess(pobj) {
    var sobj = {
      "actionType": pobj.action_type,
      "actionBody": pobj
    }
    var tokenInfo = await this.getCenterToken();
    if (tokenInfo.status != 0) {
      return {
        "requestId": self.getUUID(),
        "success": true,
        "errorMsg": "",
        "errorCode": "ok"
      };
    }
    var userpin = "";
    if (pobj.phone) {
      //获取用户userpin
      var userparam = {
        actionType: "getLoginByUserName",
        actionBody: {
          "channelUserId": pobj.phone,
          "mobile": pobj.phone,
          "userName": pobj.phone
        }
      };
      var self=this;
      // pobj.actionBody.channelUserId = pobj.mobile;//渠道用户id，没有则用手机号
      // pobj.actionBody.mobile = pobj.mobile;//用户手机号
      var url = settings.centerChannelUrl() + "/api/auth/accessAuth/springBoard";
      var userpinResultTmp = await this.execlient.execPostTK(userparam, url, tokenInfo.data.token);
      if (userpinResultTmp.status != 0 && userpinResultTmp.status != 2060) {
        return {
          "requestId": self.getUUID(),
          "success": false,
          "errorMsg": "网络错误",
          "errorCode": "ok"
        };
      }
      userpin = userpinResultTmp.data.userpin;
      if (!userpin) {
        return {
          "requestId": self.getUUID(),
          "success": false,
          "errorMsg": "网络错误",
          "errorCode": "ok"
        };
      }
    }
    //带userpin请求
    url = settings.centerChannelUrl() + "/api/opreceive/ic/springBoard";
    var token = tokenInfo.data.token;
    var rtn = rtn = await this.execlient.execDataPostByTokenUserPin(sobj, url, token, userpin);
    if (!rtn || !rtn.stdout) {
      return {
        "requestId": self.getUUID(),
        "success": false,
        "errorMsg": "网络错误",
        "errorCode": "ok"
      };
    }
    var result = JSON.parse(rtn.stdout);
    if (result.status == 0) {
      return {
        "requestId": result.requestId,
        "success": true,
        "errorMsg": "",
        "errorCode": "ok"
      };
    } else {
      return {
        "requestId": result.requestId,
        "success": false,
        "errorMsg": result.msg,
        "errorCode": "ok"
      };
    }
  }

}
module.exports = UtilsNeedSve;
